#[derive(TreeHash)]
{
// Attributes available to this derive:
#[tree_hash]
}
Implements tree_hash::TreeHash for some struct.
Fields are hashed in the order they are defined.
#[derive(TreeHash)]
{
// Attributes available to this derive:
#[tree_hash]
}
Implements tree_hash::TreeHash for some struct.
Fields are hashed in the order they are defined.